@@ -91,7 +91,6 @@ class table_objects:
                             )
         self.obj.columns = list(self.obj.columns)
         self.obj.columns.append(new_column)
-        self.obj.columns = tuple(self.obj.columns)
         return new_column
 
     def delete(self, *args, **kwargs):
@@ -194,7 +193,7 @@ class SqleeColumn:
     @property
     def data(self):
         """ Usage: data """
-        return tuple(model_to_data(self.datas))
+        return model_to_data(self.datas)
 
     @property
     def length(self):
@@ -281,7 +280,6 @@ class SqleeTable:
                     namespace = self.namespace,
                     )
                 )
-        self.columns = tuple(self.columns)
         self._loaded = True
         return self.columns
 
